==> tiles-autotag_1.1.0.orig.tar.xz: tiles-autotag-1.1.0/tiles-autotag-core/src/main/java/org/apache/tiles/autotag/generate/TemplateSuiteGenerator.java <==
/*
 * $Id: TemplateSuiteGenerator.java 1044707 2010-12-11 20:35:57Z apetrelli $
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tiles.autotag.generate;

import java.io.File;
import java.util.Map;

import org.apache.tiles.autotag.model.TemplateSuite;

/**
 * Generates code from a template suite.
 *
 * @version $Rev: 1044707 $ $Date: 2010-12-11 21:35:57 +0100 (Sat, 11 Dec 2010) $
 */
public interface TemplateSuiteGenerator {

    /**
     * Generates the code.
     *
     * @param directory The base directory where the code will be put.
     * @param packageName The package name.
     * @param suite The template suite.
     * @param parameters Configuration parameters.
     */
    void generate(File directory, String packageName, TemplateSuite suite, Map<String, String> parameters);
}

==> tiles-autotag_1.2.orig.tar.xz: tiles-autotag-1.2/tiles-autotag-core/src/main/java/org/apache/tiles/autotag/generate/TemplateSuiteGenerator.java <==
/*
 * $Id: TemplateSuiteGenerator.java 1643653 2014-12-07 06:47:59Z nlebas $
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.tiles.autotag.generate;

import java.util.Map;

import org.apache.tiles.autotag.core.OutputLocator;
import org.apache.tiles.autotag.model.TemplateSuite;

/**
 * Generates code from a template suite.
 *
 * @version $Rev: 1643653 $ $Date: 2014-12-07 07:47:59 +0100 (Sun, 07 Dec 2014) $
 */
public interface TemplateSuiteGenerator {

    /**
     * Generates the code.
     *
     * @param outputLocator The base directory where the code will be put.
     * @param packageName The package name.
     * @param suite The template suite.
     * @param parameters Configuration parameters.
     */
    void generate(OutputLocator outputLocator, String packageName, TemplateSuite suite, Map<String, String> parameters);
}
